#include <array>
#include <cassert>
#include <iostream>
#include <vector>
using namespace std;

struct LazySegmentTree {
	struct Node {
		int l, r, lc;
		int u;
		Node(int l, int r) : l(l), r(r), lc(-1), u(0) {}
	};
	int N;
	vector<Node> tree;
	LazySegmentTree(size_t n = 1) : N(n) {
		tree.reserve(2 * N - 1);
		tree.push_back({0, N});
		build(0, 0, N);
	}
	void build(int i, int l, int r) {
		auto &n = tree[i];
		if(r > l + 1) {
			int m = (l + r) / 2;
			n.lc  = tree.size();
			tree.push_back({l, m});
			tree.push_back({m, r});
			build(n.lc, l, m);
			build(n.lc + 1, m, r);
		}
	}
	int query(int l, int i = 0) {
		auto &n = tree[i];
		if(l + 1 <= n.l || n.r <= l) return 0;
		if(l <= n.l && n.r <= l + 1) return n.u;
		return query(l, n.lc) + n.u + query(l, n.lc + 1);
	}
	void update(int l, int r, int u, int i = 0) {
		auto &n = tree[i];
		if(r <= n.l || n.r <= l) return;
		if(l <= n.l && n.r <= r) return n.u += u, void();
		update(l, r, u, n.lc);
		update(l, r, u, n.lc + 1);
	}
};

const int MMAX = 1e6;

struct S {
	int pos, steps;
};

struct TT {
	array<LazySegmentTree, 2> st; // for even and odd positions
	array<vector<S>, 2> diffs;
	TT(int n) {
		for(auto &s : st) s = LazySegmentTree(MMAX / 2 + 1);

		// how many jumps do we need to go i to the left/right?
		diffs[0].push_back({0, 0});
		diffs[1].push_back({-1, 0});
		for(int i = 1, dist = 1; dist <= MMAX + 4000; ++i, dist += i)
			diffs[dist % 2].push_back({dist, i});
	}

	void update(int pos, int delta) {
		for(auto p : {0, 1}) {
			auto q = (p + pos) % 2;
			// to the right
			for(size_t i = 0; i + 1 < diffs[p].size() && pos + diffs[p][i].pos <= MMAX; ++i) {
				// the +2 must be within the division, to make sure -1 is rounded the right way
				int l = (pos + diffs[p][i].pos + 2) / 2;
				int r = (pos + diffs[p][i + 1].pos) / 2 + 1;
				st[q].update(l, r, delta * diffs[p][i + 1].steps);
			}

			// to the left
			for(size_t i = 0; i + 1 < diffs[p].size() && pos - diffs[p][i].pos > 1; ++i) {
				int l = (pos - diffs[p][i + 1].pos) / 2;
				int r = (pos - diffs[p][i].pos) / 2;
				st[q].update(l, r, delta * diffs[p][i + 1].steps);
			}
		}
	}

	int query(int pos) { return st[pos % 2].query(pos / 2); }
};

int main() {
	int n, p;
	cin >> n >> p;
	TT t(n);
	while(n--) {
		int pos;
		cin >> pos;
		t.update(pos, 1);
	}
	int q;
	cin >> q;
	while(q--) {
		char c;
		cin >> c;
		int pos;
		cin >> pos;
		if(c == 't')
			p = pos;
		else if(c == '+')
			t.update(pos, 1);
		else if(c == '-')
			t.update(pos, -1);
		else
			assert(false);
		cout << t.query(p) << '\n';
	}
	return 0;
}
