#include <bits/stdc++.h>
using namespace std;

using ll = long long;
using vi = vector<ll>;

constexpr int D = 1000010;

// Point query / range update over [0..N)
template <int N>
struct SegmentTree {
	ll v = 0LL;
	SegmentTree *lc = nullptr, *rc = nullptr;

	void update(int l, int r, ll u, int lr = 0, int rr = N - 1) {
		if (r < lr || rr < l) return;
		if (l <= lr && rr <= r) {
			v += u;
			return;
		}

		_push_to_children();

		int mr = (lr + rr) / 2;
		lc->update(l, r, u, lr, mr);
		rc->update(l, r, u, mr + 1, rr);
	}
	ll query(int p, int lr = 0, int rr = N - 1) {
		if (lr == rr) return v;

		_push_to_children();

		int mr = (lr + rr) / 2;
		if (p <= mr)
			return lc->query(p, lr, mr);
		else
			return rc->query(p, mr + 1, rr);
	}

private:
	void _push_to_children() {
		if (lc == nullptr)
			_make_children();
		lc->v += v;
		rc->v += v;
		v = 0LL;
	}

	void _make_children() {
		lc = new SegmentTree();
		rc = new SegmentTree();
	}
};

// Jumping to a position in [l, r] costs `cost`.
struct interval { int l, r, cost; };
bool interval_compare(const interval &a, const interval &b) {
	return a.l < b.l;
}

void update_around(int p, SegmentTree<D> &ft, vector<interval> &ivs, int m) {
	for (const interval &iv : ivs)
		ft.update(p + iv.l, p + iv.r, m * iv.cost);
}
void add_frog(int p, SegmentTree<D> &fteven, SegmentTree<D> &ftodd,
		vector<interval> &even, vector<interval> &odd, int m = 1) {
	update_around(p, fteven, (p&1) ? odd : even, m);
	update_around(p, ftodd, (p&1) ? even : odd, m);
}
void remove_frog(int p, SegmentTree<D> &fteven, SegmentTree<D> &ftodd,
		vector<interval> &even, vector<interval> &odd) {
	add_frog(p, fteven, ftodd, even, odd, -1);
}

int main() {
	ios::sync_with_stdio(false);
	cin.tie(NULL);

	// Preprocessing: Get costs to all even/odd positions at a large enough
	// distance.
	vector<interval> even, odd;
	{
		// Initialize with [0, 0] having cost 0.
		even.push_back(interval{0, 0, 0});
		odd.push_back(interval{0, 0, 0});
		int jumps = 0, d = 0;
		while (min(even.back().r, odd.back().r) < D) {
			// Jump!
			jumps++, d += jumps;

			// Add a new interval. We can reach everything upto distance `d`
			// with `jumps` jumps, so long as the parity of the position and
			// `d` are the same.
			vector<interval> &type = (d&1) ? odd :even;
			type.push_back(interval{type.back().r + 1, d, jumps});
		}
		// Mirror in both directions. Start at 1 to avoid [0, 0].
		size_t E = even.size(), O = odd.size();
		for (size_t i = 1; i < E; ++i)
			even.push_back(interval{-even[i].r, -even[i].l, even[i].cost});
		for (size_t i = 1; i < O; ++i)
			odd.push_back(interval{-odd[i].r, -odd[i].l, odd[i].cost});
		sort(even.begin(), even.end(), interval_compare);
		sort(odd.begin(), odd.end(), interval_compare);
	}

	// Range updates / point queries.
	SegmentTree<D> fteven, ftodd;

	int n, t;
	cin >> n >> t;
	while (n--) {
		int p;
		cin >> p;
		add_frog(p, fteven, ftodd, even, odd);
	}

	int C;
	cin >> C;
	while (C--) {
		char q; int a;
		cin >> q >> a;
		if (q == '+')
			add_frog(a, fteven, ftodd, even, odd);
		else if (q == '-')
			remove_frog(a, fteven, ftodd, even, odd);
		else // q == 't'
			t = a;

		cout << ((t&1) ? ftodd.query(t) : fteven.query(t)) << '\n';
	}
}
