#include <algorithm>
#include <array>
#include <cassert>
#include <iostream>
#include <vector>
using namespace std;

const int MMAX = 1e6 + 4000;

struct T {
	vector<pair<int, int>> frogs;
	array<int, MMAX> dist;

	T(int n) {
		for(int pos = 0, i = 0; pos < MMAX; ++i, pos += i) dist[pos] = i;
		for(int i                    = MMAX - 3; i > 0; --i)
			if(dist[i] == 0) dist[i] = dist[i + 2];
	}

	void update(int pos, int delta) {
		auto it = frogs.begin();
		while(it != frogs.end() && it->first != pos) ++it;
		if(delta == 1) {
			if(it == frogs.end())
				frogs.push_back({pos, 1});
			else
				++it->second;
		} else
			--it->second;
	}

	int query(int pos) {
		int ans = 0;
		for(auto x : frogs) ans += x.second * dist[abs(pos - x.first)];
		return ans;
	}
};

int main() {
	int n, p;
	cin >> n >> p;
	T t(n);
	while(n--) {
		int pos;
		cin >> pos;
		t.update(pos, 1);
	}
	int q;
	cin >> q;
	while(q--) {
		char c;
		cin >> c;
		int pos;
		cin >> pos;
		if(c == 't')
			p = pos;
		else if(c == '+')
			t.update(pos, 1);
		else if(c == '-')
			t.update(pos, -1);
		else
			assert(false);
		cout << t.query(p) << '\n';
	}
	return 0;
}
